@@ -45,7 +45,25 @@ def plot_wikipedia_cdfs():
     plt.show()
 
 
+def plot_increasing_alpha_beta():
+
+    ax = new_axes()
+    x = arange(0, 1.001, 0.001)
+    Gamma(alpha=4, beta=10).pdf().plot(x=x, color='red', ax=ax)
+    Gamma(alpha=8, beta=20).pdf().plot(x=x, color='red', ax=ax)
+    Gamma(alpha=16, beta=40).pdf().plot(x=x, color='orange', ax=ax)
+    Gamma(alpha=32, beta=80).pdf().plot(x=x, color='yellow', ax=ax)
+    Gamma(alpha=64, beta=160).pdf().plot(x=x, color='green', ax=ax)
+    Gamma(alpha=128, beta=320).pdf().plot(x=x, color='black', ax=ax)
+    Gamma(alpha=256, beta=640).pdf().plot(x=x, color='blue', ax=ax)
+    Gamma(alpha=512, beta=1280).pdf().plot(x=x, color='purple', ax=ax)
+    ax.set_xlim(0, 1)
+    ax.legend(loc='lower right')
+    plt.show()
+
+
 if __name__ == '__main__':
 
-    plot_wikipedia_pdfs()
-    plot_wikipedia_cdfs()
+    # plot_wikipedia_pdfs()
+    # plot_wikipedia_cdfs()
+    plot_increasing_alpha_beta()
