@@ -14,9 +14,12 @@ def plot_wikipedia_pmfs():
     https://en.wikipedia.org/wiki/Poisson_distribution#/media/File:Poisson_pmf.svg
     """
     ax = new_axes(width=10, height=10)
-    Poisson(lambda_=1).plot(k=k_wikipedia, kind='line', color='gray', mfc='orange', marker='o', ax=ax)
-    Poisson(lambda_=4).plot(k=k_wikipedia, kind='line', color='gray', mfc='purple', marker='o', ax=ax)
-    Poisson(lambda_=10).plot(k=k_wikipedia, kind='line', color='gray', mfc='lightblue', marker='o', ax=ax)
+    Poisson(lambda_=1).plot(k=k_wikipedia, kind='line',
+                            color='gray', mfc='orange', marker='o', ax=ax)
+    Poisson(lambda_=4).plot(k=k_wikipedia, kind='line',
+                            color='gray', mfc='purple', marker='o', ax=ax)
+    Poisson(lambda_=10).plot(k=k_wikipedia, kind='line',
+                             color='gray', mfc='lightblue', marker='o', ax=ax)
     ax.set_ylim(0, 0.4)
     ax.set_title('Probability mass function')
     ax.legend(loc='upper right')
@@ -28,9 +31,12 @@ def plot_wikipedia_cdfs():
     https://en.wikipedia.org/wiki/Poisson_distribution#/media/File:Poisson_pmf.svg
     """
     ax = new_axes(width=10, height=10)
-    Poisson(lambda_=1).cdf().plot(k=k_wikipedia, color='gray', mfc='orange', marker='o', ax=ax)
-    Poisson(lambda_=4).cdf().plot(k=k_wikipedia, color='gray', mfc='purple', marker='o', ax=ax)
-    Poisson(lambda_=10).cdf().plot(k=k_wikipedia, color='gray', mfc='lightblue', marker='o', ax=ax)
+    Poisson(lambda_=1).cdf().plot(k=k_wikipedia, color='gray',
+                                  mfc='orange', marker='o', ax=ax)
+    Poisson(lambda_=4).cdf().plot(k=k_wikipedia, color='gray',
+                                  mfc='purple', marker='o', ax=ax)
+    Poisson(lambda_=10).cdf().plot(k=k_wikipedia, color='gray',
+                                   mfc='lightblue', marker='o', ax=ax)
     ax.set_title('Cumulative distribution function')
     ax.legend(loc='lower right')
     plt.show()
