@@ -3,7 +3,9 @@ from scipy.stats import invgamma, rv_continuous
 from probability.distributions.mixins.attributes import AlphaFloatDMixin, \
     BetaFloatDMixin
 from probability.distributions.mixins.calculable_mixins import CalculableMixin
-from probability.distributions.mixins.rv_continuous_1d_mixin import RVContinuous1dMixin
+from probability.distributions.mixins.rv_continuous_1d_mixin import \
+    RVContinuous1dMixin
+from probability.utils import num_format
 
 
 class InvGamma(
@@ -41,7 +43,11 @@ class InvGamma(
 
     def __str__(self):
 
-        return f'InvGamma(α={self._alpha}, β={self._beta})'
+        return (
+            f'InvGamma('
+            f'α={num_format(self._alpha, 3)}, '
+            f'β={num_format(self._beta, 3)})'
+        )
 
     def __repr__(self):
 
